Changelog
=========


0.0.2 (2024-08-20)
------------------

Fix
~~~
- Test errors. [Huajian Mao]

Other
~~~~~
- Release: version 0.0.2 🚀 [Huajian Mao]
- Release: version 0.0.2 🚀 [Huajian Mao]
- Chore: remove useless files. [Huajian Mao]
- Release: v0.0.1. [Huajian Mao]
- Chore: revise permission of release script. [Huajian Mao]
- Merge pull request #4 from
  bioinfox/dependabot/github_actions/actions/setup-python-5. [Huajian
  Mao]

  build(deps): bump actions/setup-python from 4 to 5
- Build(deps): bump actions/setup-python from 4 to 5. [dependabot[bot]]

  Bumps [actions/setup-python](https://github.com/actions/setup-python) from 4 to 5.
  - [Release notes](https://github.com/actions/setup-python/releases)
  - [Commits](https://github.com/actions/setup-python/compare/v4...v5)

  ---
  updated-dependencies:
  - dependency-name: actions/setup-python
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Merge pull request #3 from
  bioinfox/dependabot/github_actions/actions/checkout-4. [Huajian Mao]

  build(deps): bump actions/checkout from 3 to 4
- Build(deps): bump actions/checkout from 3 to 4. [dependabot[bot]]

  Bumps [actions/checkout](https://github.com/actions/checkout) from 3 to 4.
  - [Release notes](https://github.com/actions/checkout/releases)
  - [Changelog](https://github.com/actions/checkout/blob/main/CHANGELOG.md)
  - [Commits](https://github.com/actions/checkout/compare/v3...v4)

  ---
  updated-dependencies:
  - dependency-name: actions/checkout
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Merge pull request #2 from
  bioinfox/dependabot/github_actions/softprops/action-gh-release-2.
  [Huajian Mao]

  build(deps): bump softprops/action-gh-release from 1 to 2
- Build(deps): bump softprops/action-gh-release from 1 to 2.
  [dependabot[bot]]

  Bumps [softprops/action-gh-release](https://github.com/softprops/action-gh-release) from 1 to 2.
  - [Release notes](https://github.com/softprops/action-gh-release/releases)
  - [Changelog](https://github.com/softprops/action-gh-release/blob/master/CHANGELOG.md)
  - [Commits](https://github.com/softprops/action-gh-release/compare/v1...v2)

  ---
  updated-dependencies:
  - dependency-name: softprops/action-gh-release
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Merge pull request #1 from
  bioinfox/dependabot/github_actions/codecov/codecov-action-4. [Huajian
  Mao]

  build(deps): bump codecov/codecov-action from 3 to 4
- Build(deps): bump codecov/codecov-action from 3 to 4.
  [dependabot[bot]]

  Bumps [codecov/codecov-action](https://github.com/codecov/codecov-action) from 3 to 4.
  - [Release notes](https://github.com/codecov/codecov-action/releases)
  - [Changelog](https://github.com/codecov/codecov-action/blob/main/CHANGELOG.md)
  - [Commits](https://github.com/codecov/codecov-action/compare/v3...v4)

  ---
  updated-dependencies:
  - dependency-name: codecov/codecov-action
    dependency-type: direct:production
    update-type: version-update:semver-major
  ...
- Chore: revise release environment. [Huajian Mao]
- Init: from python-project-template. [Huajian Mao]


